import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

import Input from 'reactstrap/lib/Input';

import { IconDotPreloader } from '../../icons/icon-dot-preloader/icon-dot-preloader';

import './input-with-icon.scss';

export function InputWithIcon({
  icon, value, isLoading, className, ...rest
}) {
  return (
    <div className="input-with-icon w-100 position-relative">
      <Input
        {...rest}
        value={isLoading ? '' : value}
        disabled={isLoading}
        className={classNames(className, 'pl-2 pr-5', { 'bg-white': isLoading })}
      />
      <span className="d-flex input-icon position-absolute">{icon}</span>
      {isLoading && <IconDotPreloader className="dot-preloader h5p text-gray-dark-hint position-absolute" />}
    </div>
  );
}

InputWithIcon.propTypes = {
  icon: PropTypes.node.isRequired,
  value: PropTypes.string,
  isLoading: PropTypes.bool,
  className: PropTypes.string,
};

InputWithIcon.defaultProps = {
  value: '',
  isLoading: false,
  className: '',
};
