import React from 'react';
import Button from 'reactstrap/lib/Button';
import { ServicesMenu } from './services-menu';
import { testURL } from '../../../jest.config';


describe('<ServicesMenu />', () => {
  let wrapper;
  const hostname = testURL;
  const e = {
    currentTarget: {
      dataset: {
        action: 'test-action',
      },
    },
    which: 13,
  };

  beforeAll(() => {
    wrapper = shallow(<ServicesMenu hostname={hostname} serviceItems={[]} />);
  });

  describe('when menu item is linking to the current hostname', () => {
    test('should include empty href without target to trigger page reload only', () => {
      wrapper.setProps({
        serviceItems: [
          {
            link: hostname,
            message: 'internal link',
            icon: (<Button />),
          },
        ],
      });
      expect(wrapper).toMatchSnapshot();
    });

    test('should include empty href besides protocol missing in hostname', () => {
      wrapper.setProps({
        serviceItems: [
          {
            link: hostname,
            message: 'internal link',
            icon: (<Button />),
          },
        ],
        hostname: 'wallet.scorum.com',
      });
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('when menu item is linking to external url', () => {
    test('should contain href url with blank target', () => {
      wrapper.setProps({
        serviceItems: [
          {
            link: 'https://blog.scorum.com',
            message: 'external link',
            icon: (<Button />),
          },
        ],
      });
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('popover', () => {
    test('should toggle popover menu with ga action', () => {
      wrapper.instance().toggleMenu();
      expect(wrapper.state().menuOpen).toBe(true);
    });
  });

  describe('popover', () => {
    test('should toggle popover menu', () => {
      wrapper.instance().toggleMenu();
      expect(wrapper.state().menuOpen).toBe(false);
    });
  });

  describe('fireAction', () => {
    test('should fire ga action', () => {
      wrapper.instance().fireAction(e);
    });
  });

  describe('serviceKeyPress', () => {
    test('should fire event when enter pressed', () => {
      wrapper.instance().serviceKeyPress(e);
    });
  });

  describe('fireAction', () => {
    test('should not fire event when other key pressed', () => {
      wrapper.instance().serviceKeyPress({ which: 10 });
    });

    test('should not fire event when other key pressed keyCode', () => {
      wrapper.instance().serviceKeyPress({ keyCode: 10 });
    });
  });
});
